@@ -25,7 +25,7 @@ _RESERVED = {'_G', 'BDR', 'SCN', 'BOOT', 'TIC', 'OVR', 'MENU', '_VERSION',
              'pairs', 'pcall', 'peek', 'peek1', 'peek2', 'peek4', 'pix', 'pmem',
              'poke', 'poke1', 'poke2', 'poke4', 'print', 'rawequal', 'rawget',
              'rawlen', 'rawset', 'rect', 'rectb', 'require', 'reset', 'select',
-             'setmetatable', 'sfx', 'spr', 'str', 'string', 'sync', 'table',
+             'self', 'setmetatable', 'sfx', 'spr', 'str', 'string', 'sync', 'table',
              'textri', 'time', 'tonumber', 'tostring', 'trace', 'tri', 'trib',
              'tstamp', 'ttri', 'type', 'vbank', 'xpcall'}
 _TWO = ast.Numeral(2)
@@ -172,8 +172,9 @@ def mutate(root: ast.Node, rand: random.Random) -> ast.Node:
         return _mut
     used_labels = sorted(used_labels)
     mutations.extend((label_repl(a, b) for a in used_labels for b in _LOWERS if a != b))
-    mutation = rand.choice(mutations)
-    mutation()
+    if len(mutations) > 0:
+        mutation = rand.choice(mutations)
+        mutation()
     return new_root
 
 
@@ -441,8 +442,15 @@ def _(node: ast.Field, visitor: Callable[[ast.Node], None]):
 
 
 @ visit.register(ast.MethodCall)
+def _(node: ast.MethodCall, visitor: Callable[[ast.Node], None]):
+    visitor(node)
+    visit(node.value, visitor)
+    for a in node.args:
+        visit(a, visitor)
+
+
 @ visit.register(ast.Call)
-def _(node: Union[ast.Call, ast.MethodCall], visitor: Callable[[ast.Node], None]):
+def _(node: ast.Call, visitor: Callable[[ast.Node], None]):
     visitor(node)
     visit(node.func, visitor)
     for a in node.args:
